@@ -1,7 +1,6 @@
 from copy import deepcopy
 
 from metrics_layer.core.exceptions import QueryError, JoinError
-from metrics_layer.core.parse.config import MetricsLayerConfiguration
 from metrics_layer.core.sql.single_query_resolve import SingleSQLQueryResolver
 from metrics_layer.core.sql.merged_query_resolve import MergedSQLQueryResolver
 from metrics_layer.core.sql.query_base import QueryKindTypes
@@ -26,7 +25,8 @@ class SQLQueryResolver(SingleSQLQueryResolver):
         where: str = None,  # Either a list of json or a string
         having: str = None,  # Either a list of json or a string
         order_by: str = None,  # Either a list of json or a string
-        config: MetricsLayerConfiguration = None,
+        project=None,
+        model=None,
         **kwargs,
     ):
         self.field_lookup = {}
@@ -37,8 +37,7 @@ class SQLQueryResolver(SingleSQLQueryResolver):
         self.suppress_warnings = kwargs.get("suppress_warnings", False)
         self.limit = kwargs.get("limit")
         self.single_query = kwargs.get("single_query", False)
-        self.config = config
-        self.project = self.config.project
+        self.project = project
         self.metrics = metrics
         self.dimensions = dimensions
         self.funnel = funnel
@@ -46,20 +45,7 @@ class SQLQueryResolver(SingleSQLQueryResolver):
         self.having = having
         self.order_by = order_by
         self.kwargs = kwargs
-        self.connection = None
-
-        model_name = self.kwargs.get("model_name")
-        models = self.project.models()
-
-        # If you specify the model that's top priority
-        if model_name:
-            self.model = self.project.get_model(model_name)
-        # Otherwise, if there's only one option, we use that
-        elif len(models) == 1:
-            self.model = models[0]
-        # Finally, check views for models
-        else:
-            self.model = self._derive_model()
+        self.model = model
 
     @property
     def is_merged_result(self):
@@ -102,11 +88,10 @@ class SQLQueryResolver(SingleSQLQueryResolver):
             having=self.having,
             order_by=self.order_by,
             model=self.model,
-            config=self.config,
+            project=self.project,
             **self.kwargs,
         )
         query = resolver.get_query(semicolon)
-        self.connection = resolver.connection
         return query
 
     def _get_merged_result_query(self, semicolon: bool):
@@ -118,27 +103,8 @@ class SQLQueryResolver(SingleSQLQueryResolver):
             having=self.having,
             order_by=self.order_by,
             model=self.model,
-            config=self.config,
+            project=self.project,
             **self.kwargs,
         )
         query = resolver.get_query(semicolon)
-        self.connection = resolver.connection
         return query
-
-    def _derive_model(self):
-        all_fields = self.metrics + self.dimensions
-        all_model_names = {f.view.model_name for f in all_fields}
-
-        if len(all_model_names) == 0:
-            raise QueryError(
-                "No models found in this data model. Please specify a model "
-                "to connect a data warehouse to your data model."
-            )
-        elif len(all_model_names) == 1:
-            return self.project.get_model(list(all_model_names)[0])
-        else:
-            raise QueryError(
-                "More than one model found in this data model. Please specify a model "
-                "to use by either passing the name of the model using 'model_name' parameter or by  "
-                "setting the `model_name` property on the view."
-            )
